@@ -1,3 +1,8 @@
+from __future__ import annotations
+
+from collections.abc import Iterable
+from pathlib import Path
+
 import click
 
 from .catalog import fetch_catalog, clean_catalog, update_catalog
@@ -10,6 +15,7 @@ from .cluster import (
 )
 from .config import Config
 from .dependency_mgmt import (
+    create_component_library_aliases,
     fetch_components,
     fetch_jsonnet_libraries,
     register_components,
@@ -24,10 +30,32 @@ from .helpers import (
     kapitan_inventory,
     rm_tree_contents,
 )
+from .inventory.lint import check_removed_reclass_variables
 from .postprocess import postprocess_components
 from .refs import update_refs
 
 
+def check_removed_reclass_variables_inventory(config: Config, tenant: str):
+    paths = [
+        # global defaults
+        config.inventory.global_config_dir,
+        # tenant repo
+        config.inventory.tenant_config_dir(tenant),
+    ]
+
+    check_removed_reclass_variables(config, "hierarchy", paths)
+
+
+def check_removed_reclass_variables_components(config: Config):
+    paths: Iterable[Path] = sum(
+        # defaults.yml and <component-name>.yml for all enabled components
+        [[c.defaults_file, c.class_file] for c in config.get_components().values()],
+        [],
+    )
+
+    check_removed_reclass_variables(config, "enabled components", paths)
+
+
 def _fetch_global_config(cfg: Config, cluster: Cluster):
     click.secho("Updating global config...", bold=True)
     repo = GitRepo(cluster.global_git_repo_url, cfg.inventory.global_config_dir)
@@ -63,6 +91,7 @@ def _regular_setup(config: Config, cluster_id):
     # Fetch components and config
     _fetch_global_config(config, cluster)
     _fetch_customer_config(config, cluster)
+    check_removed_reclass_variables_inventory(config, cluster.tenant_id)
     fetch_components(config)
 
     update_target(config, config.inventory.bootstrap_target)
@@ -103,6 +132,8 @@ def _local_setup(config: Config, cluster_id):
         "customer", GitRepo(None, config.inventory.tenant_config_dir(tenant))
     )
 
+    check_removed_reclass_variables_inventory(config, tenant)
+
     click.secho("Resetting targets...", bold=True)
     rm_tree_contents(config.inventory.targets_dir)
 
@@ -123,17 +154,18 @@ def _local_setup(config: Config, cluster_id):
     return GitRepo(None, config.catalog_dir)
 
 
-def check_parameters_component_versions(config: Config, cluster_parameters):
+def check_parameters_component_versions(cluster_parameters):
     """
-    Deprecation handler for `parameters.component_versions`.
+    Check inventory for `parameters.component_versions`.
 
-    Registers a deprecation notice if uses of `parameters.component_versions`
-    are found in the rendered inventory.
+    Raise an error if the parameter has any contents.
     """
     cvers = cluster_parameters.get("component_versions", {})
     if len(cvers.keys()) > 0:
-        config.register_deprecation_notice(
-            "`parameters.component_versions` is deprecated, please migrate to `parameters.components`"
+        raise click.ClickException(
+            "Specifying component versions in parameter `component_versions` "
+            + "is no longer suppported. Please migrate your configuration to "
+            + "parameter `components`."
         )
 
 
@@ -145,9 +177,13 @@ def compile(config, cluster_id):
         clean_working_tree(config)
         catalog_repo = _regular_setup(config, cluster_id)
 
+    # Raise error if any enabled components use removed reclass variables
+    check_removed_reclass_variables_components(config)
+
     inventory = kapitan_inventory(config)
     cluster_parameters = inventory[config.inventory.bootstrap_target]["parameters"]
-    check_parameters_component_versions(config, cluster_parameters)
+    check_parameters_component_versions(cluster_parameters)
+    create_component_library_aliases(config, cluster_parameters)
 
     # Verify that all aliased components support instantiation
     config.verify_component_aliases(cluster_parameters)
