@@ -1,5 +1,8 @@
+from __future__ import annotations
+
+from collections.abc import Iterable
 from pathlib import Path as P
-from typing import Iterable, Optional
+from typing import Optional
 
 import _jsonnet
 import click
@@ -79,9 +82,16 @@ class Component:
 
         return []
 
-    @property
-    def filters_file(self) -> P:
-        return self.target_directory / "postprocess" / "filters.yml"
+    def get_library(self, libname: str) -> Optional[P]:
+        lib_dir = self.target_directory / "lib"
+        if not lib_dir.exists():
+            return None
+
+        for f in self.lib_files:
+            if f.absolute() == P(lib_dir / libname).absolute():
+                return f.absolute()
+
+        return None
 
     @property
     def parameters_key(self):
