@@ -1,14 +1,20 @@
+from __future__ import annotations
+
+import time
 import textwrap
 
 from enum import Enum
 from pathlib import Path as P
-from typing import Dict, List, Optional
+from typing import Optional
+
+import jwt
 
 import click
 
 from commodore.component import Component, component_parameters_key
 from .gitrepo import GitRepo
 from .inventory import Inventory
+from . import tokencache
 
 
 class Migration(Enum):
@@ -18,12 +24,15 @@ class Migration(Enum):
 # pylint: disable=too-many-instance-attributes,too-many-public-methods
 class Config:
     _inventory: Inventory
-    _components: Dict[str, Component]
-    _config_repos: Dict[str, GitRepo]
-    _component_aliases: Dict[str, str]
-    _deprecation_notices: List[str]
+    _components: dict[str, Component]
+    _config_repos: dict[str, GitRepo]
+    _component_aliases: dict[str, str]
+    _deprecation_notices: list[str]
     _migration: Optional[Migration]
 
+    oidc_client: Optional[str]
+    oidc_discovery_url: Optional[str]
+
     # pylint: disable=too-many-arguments
     def __init__(
         self,
@@ -37,6 +46,8 @@ class Config:
         self._work_dir = work_dir.resolve()
         self.api_url = api_url
         self.api_token = api_token
+        self.oidc_client = None
+        self.oidc_discovery_url = None
         self._components = {}
         self._config_repos = {}
         self._component_aliases = {}
@@ -97,6 +108,20 @@ class Config:
 
     @property
     def api_token(self):
+        if self._api_token is None and self.api_url:
+            token = tokencache.get(self.api_url)
+            if token is not None:
+                # We don't verify the signature, we just want to know if the token is expired
+                # lieutenant will decide if it's valid
+                try:
+                    t = jwt.decode(
+                        token, algorithms=["RS256"], options={"verify_signature": False}
+                    )
+                    if "exp" in t and t["exp"] < time.time() + 10:
+                        return None
+                except jwt.exceptions.InvalidTokenError:
+                    return None
+                self._api_token = token
         return self._api_token
 
     @api_token.setter
@@ -114,6 +139,8 @@ class Config:
                 else:
                     raise
             self._api_token = api_token.strip()
+        else:
+            self._api_token = None
 
     @property
     def global_repo_revision_override(self):
@@ -165,30 +192,12 @@ class Config:
     def get_component_aliases(self):
         return self._component_aliases
 
-    def register_component_aliases(self, aliases: Dict[str, str]):
+    def register_component_aliases(self, aliases: dict[str, str]):
         self._component_aliases = aliases
 
-    def _component_is_aliasable(self, cluster_parameters: Dict, component_name: str):
-        ckey = component_parameters_key(component_name)
-        deprecation_notice_url = (
-            "https://syn.tools/commodore/reference/"
-            + "deprecation-notices.html#_multi_instance_top_level"
-        )
-        if "multi_instance" in cluster_parameters[ckey]:
-            self.register_deprecation_notice(
-                f"Component `{component_name}` advertises multi-instance support in "
-                + "component parameter `multi_instance`. This has been deprecated "
-                + "in favor of using `_metadata.multi_instance`. "
-                + f"See {deprecation_notice_url} for more details."
-            )
-            return cluster_parameters[ckey]["multi_instance"]
-
-        cmeta = cluster_parameters[ckey].get("_metadata", {})
-        return cmeta.get("multi_instance", False)
-
-    def verify_component_aliases(self, cluster_parameters: Dict):
+    def verify_component_aliases(self, cluster_parameters: dict):
         for alias, cn in self._component_aliases.items():
-            if alias != cn and not self._component_is_aliasable(cluster_parameters, cn):
+            if alias != cn and not _component_is_aliasable(cluster_parameters, cn):
                 raise click.ClickException(
                     f"Component {cn} with alias {alias} does not support instantiation."
                 )
@@ -223,3 +232,9 @@ class Config:
                 if "deprecation_notice" in cmeta:
                     msg += f" {cmeta['deprecation_notice']}"
                 self.register_deprecation_notice(msg)
+
+
+def _component_is_aliasable(cluster_parameters: dict, component_name: str):
+    ckey = component_parameters_key(component_name)
+    cmeta = cluster_parameters[ckey].get("_metadata", {})
+    return cmeta.get("multi_instance", False)
