@@ -1,8 +1,11 @@
+from __future__ import annotations
+
 import os
 import json
+from collections.abc import Iterable
 from pathlib import Path as P
 from subprocess import call  # nosec
-from typing import Any, Dict, Iterable, List, Optional, Tuple, Set
+from typing import Any, Optional
 
 import click
 
@@ -11,22 +14,17 @@ from .component import Component, component_dir
 from .helpers import relsymlink, kapitan_inventory
 
 
-def validate_component_library_name(cfg: Config, cname: str, lib: P) -> P:
+def validate_component_library_name(cname: str, lib: P) -> P:
     if not lib.stem.startswith(cname):
-        deprecation_notice_url = (
-            "https://syn.tools/commodore/reference/"
-            + "deprecation-notices.html#_component_lib_naming"
-        )
-        cfg.register_deprecation_notice(
-            f"Component '{cname}' uses component library name {lib.name} "
-            + "which isn't prefixed with the component's name. "
-            + f"See {deprecation_notice_url} for more details."
+        raise click.ClickException(
+            f"Component '{cname}' uses invalid component library name '{lib.name}'. "
+            + "Consider using a library alias."
         )
 
     return lib
 
 
-def _check_library_alias_prefixes(libalias: str, cn: str, component_prefixes: Set[str]):
+def _check_library_alias_prefixes(libalias: str, cn: str, component_prefixes: set[str]):
     for p in component_prefixes - {cn}:
         if libalias.startswith(p):
             raise click.ClickException(
@@ -35,9 +33,9 @@ def _check_library_alias_prefixes(libalias: str, cn: str, component_prefixes: Se
             )
 
 
-def _check_library_alias_collisions(cfg: Config, cluster_params: Dict[str, Any]):
+def _check_library_alias_collisions(cfg: Config, cluster_params: dict[str, Any]):
     # map of library alias to set(originating components)
-    collisions: Dict[str, Set[str]] = {}
+    collisions: dict[str, set[str]] = {}
 
     components = cfg.get_components()
     component_prefixes = set(cluster_params["components"].keys())
@@ -58,7 +56,7 @@ def _check_library_alias_collisions(cfg: Config, cluster_params: Dict[str, Any])
             )
 
 
-def create_component_library_aliases(cfg: Config, cluster_params: Dict[str, Any]):
+def create_component_library_aliases(cfg: Config, cluster_params: dict[str, Any]):
     _check_library_alias_collisions(cfg, cluster_params)
 
     for _, component in cfg.get_components().items():
@@ -98,7 +96,7 @@ def create_component_symlinks(cfg, component: Component):
         if cfg.debug:
             click.echo(f"     > installing template library: {file}")
         relsymlink(
-            validate_component_library_name(cfg, component.name, file),
+            validate_component_library_name(component.name, file),
             cfg.inventory.lib_dir,
         )
 
@@ -125,15 +123,19 @@ def _format_component_list(components: Iterable[str]) -> str:
     return formatted
 
 
-def _discover_components(cfg) -> Tuple[List[str], Dict[str, str]]:
+def _extract_component_aliases(
+    cfg: Config, kapitan_applications: Iterable[str]
+) -> tuple[set[str], dict[str, set[str]]]:
     """
-    Discover components used by the currenct cluster by extracting all entries from the
-    reclass applications dictionary.
+    Extract components and all aliases from Kapitan applications array.
+
+    This function doesn't validate the resulting data. Generally, callers will want to
+    use `_discover_components()` to extract components and their aliases from the
+    applications array.
     """
-    kapitan_applications = kapitan_inventory(cfg, key="applications")
     components = set()
-    all_component_aliases: Dict[str, Set[str]] = {}
-    for component in kapitan_applications.keys():
+    all_component_aliases: dict[str, set[str]] = {}
+    for component in kapitan_applications:
         try:
             cn, alias = component.split(" as ")
         except ValueError:
@@ -147,7 +149,24 @@ def _discover_components(cfg) -> Tuple[List[str], Dict[str, str]]:
         components.add(cn)
         all_component_aliases.setdefault(alias, set()).add(cn)
 
-    component_aliases: Dict[str, str] = {}
+    return components, all_component_aliases
+
+
+def _discover_components(cfg) -> tuple[list[str], dict[str, str]]:
+    """
+    Discover components used by the current cluster by extracting all entries from the
+    reclass applications dictionary.
+
+    The function also verifies the extracted entries, and raises an exception if any
+    invalid aliases are found.
+    """
+    kapitan_applications = kapitan_inventory(cfg, key="applications")
+
+    components, all_component_aliases = _extract_component_aliases(
+        cfg, kapitan_applications.keys()
+    )
+
+    component_aliases: dict[str, str] = {}
 
     for alias, cns in all_component_aliases.items():
         if len(cns) == 0:
@@ -193,7 +212,7 @@ def _discover_components(cfg) -> Tuple[List[str], Dict[str, str]]:
 
 def _read_components(
     cfg: Config, component_names
-) -> Tuple[Dict[str, str], Dict[str, Optional[str]]]:
+) -> tuple[dict[str, str], dict[str, Optional[str]]]:
     component_urls = {}
     component_versions = {}
 
@@ -222,14 +241,9 @@ def _read_components(
         if "version" in info:
             component_versions[component_name] = info["version"]
         else:
-            cfg.register_deprecation_notice(
-                f"Component {component_name} doesn't have a version specified. "
-                + "See https://syn.tools/commodore/reference/deprecation-notices.html"
-                + "#_components_without_versions for more details."
+            raise click.ClickException(
+                f"Component '{component_name}' doesn't have a version specified."
             )
-            # Note: We use version=None as a marker for checking out the remote repo's
-            # default branch.
-            component_versions[component_name] = None
         if cfg.debug:
             click.echo(
                 f" > Version for {component_name}: {component_versions[component_name]}"
